@@ -8,6 +8,7 @@ import requests
 from django.conf import settings
 from jwt import PyJWKClient
 from jwt.exceptions import InvalidTokenError
+from cachetools.func import ttl_cache
 
 from .decorators import keycloak_api_error_handler
 from .urls import (
@@ -349,6 +350,8 @@ class Connect:
 
         # Get the public key from the identity provider, i.e., the keycloak server
         decoded = self._decode_token(self._client_token, self.client_jwt_audience)
+        if not decoded:
+            return True
         exp = datetime.fromtimestamp(decoded["exp"], tz=timezone.utc)
         iat = datetime.fromtimestamp(decoded["iat"], tz=timezone.utc)
         now = datetime.now(tz=timezone.utc)
@@ -399,6 +402,7 @@ class Connect:
             headers["HOST"] = urlparse(self.internal_url).netloc
         return [server_url, headers]
 
+    @ttl_cache(maxsize=128, ttl=60)
     def _decode_token(
         self, token: str, audience: Union[str, List[str]], raise_error=False
     ) -> Optional[Dict]:
